@@ -1,7 +1,7 @@
 "dist.list" <-
 function() {
   dist <- c("cau","exp","gam","gev","gld","glo","gno",
-            "gpa","gum","kap","nor","pe3","revgum","wak",
+            "gpa","gum","kap","nor","pe3","ray","revgum","wak",
             "wei");
   return(dist)
 } 
